summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/opengl
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-10 12:13:27 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-10 12:13:27 -0500
commitd296f1d337dabfeae5191955fdadb874965dbbe9 (patch)
tree1a4b3b4cca01f2ea77eee2497297219d60e9bbd4 /tqtinterface/qt4/src/opengl
parenteaa7ee2e0bbca40ba3173c4304f81957e8964291 (diff)
downloadexperimental-d296f1d337dabfeae5191955fdadb874965dbbe9.tar.gz
experimental-d296f1d337dabfeae5191955fdadb874965dbbe9.zip
rename the following methods:
tqparent parent tqmask mask
Diffstat (limited to 'tqtinterface/qt4/src/opengl')
-rw-r--r--tqtinterface/qt4/src/opengl/tqgl.cpp40
-rw-r--r--tqtinterface/qt4/src/opengl/tqgl.h8
-rw-r--r--tqtinterface/qt4/src/opengl/tqgl_x11.cpp24
-rw-r--r--tqtinterface/qt4/src/opengl/tqgl_x11_p.h2
4 files changed, 37 insertions, 37 deletions
diff --git a/tqtinterface/qt4/src/opengl/tqgl.cpp b/tqtinterface/qt4/src/opengl/tqgl.cpp
index 7054e8e..77d4809 100644
--- a/tqtinterface/qt4/src/opengl/tqgl.cpp
+++ b/tqtinterface/qt4/src/opengl/tqgl.cpp
@@ -207,8 +207,8 @@ TQGLFormat::TQGLFormat()
\code
// The rendering in MyGLWidget depends on using
// stencil buffer and alpha channel
- MyGLWidget::MyGLWidget( TQWidget* tqparent, const char* name )
- : TQGLWidget( TQGLFormat( StencilBuffer | AlphaChannel ), tqparent, name )
+ MyGLWidget::MyGLWidget( TQWidget* parent, const char* name )
+ : TQGLWidget( TQGLFormat( StencilBuffer | AlphaChannel ), parent, name )
{
if ( !format().stencil() )
qWarning( "Could not get stencil buffer; results will be suboptimal" );
@@ -998,17 +998,17 @@ void TQGLContext::init( TQPaintDevice *dev )
\fn TQColor TQGLContext::overlayTransparentColor() const
If this context is a valid context in an overlay plane, returns
- the plane's transtqparent color. Otherwise returns an \link
+ the plane's transparent color. Otherwise returns an \link
TQColor::isValid() invalid \endlink color.
The returned color's \link TQColor::pixel() pixel \endlink value is
- the index of the transtqparent color in the colormap of the overlay
+ the index of the transparent color in the colormap of the overlay
plane. (Naturally, the color's RGB values are meaningless.)
The returned TQColor object will generally work as expected only
when passed as the argument to TQGLWidget::qglColor() or
TQGLWidget::qglClearColor(). Under certain circumstances it can
- also be used to draw transtqparent graphics with a TQPainter. See the
+ also be used to draw transparent graphics with a TQPainter. See the
examples/opengl/overlay_x11 example for details.
*/
@@ -1168,8 +1168,8 @@ bool TQGLContext::create( const TQGLContext* shareContext )
TQ_OBJECT // must include this if you use TQt Q_SIGNALS/Q_SLOTS
public:
- MyGLDrawer( TQWidget *tqparent, const char *name )
- : TQGLWidget(tqparent, name) {}
+ MyGLDrawer( TQWidget *parent, const char *name )
+ : TQGLWidget(parent, name) {}
protected:
@@ -1245,7 +1245,7 @@ bool TQGLContext::create( const TQGLContext* shareContext )
functions, except that they will be called when the overlay
context is made current. You can explicitly make the overlay
context current by using makeOverlayCurrent(), and you can access
- the overlay context directly (e.g. to ask for its transtqparent
+ the overlay context directly (e.g. to ask for its transparent
color) by calling overlayContext().
On X servers in which the default visual is in an overlay plane,
@@ -1292,13 +1292,13 @@ void qgl_delete_d( const TQGLWidget * w )
}
/*!
- Constructs an OpenGL widget with a \a tqparent widget and a \a name.
+ Constructs an OpenGL widget with a \a parent widget and a \a name.
The \link TQGLFormat::defaultFormat() default format\endlink is
used. The widget will be \link isValid() invalid\endlink if the
system has no \link TQGLFormat::hasOpenGL() OpenGL support\endlink.
- The \a tqparent, \a name and widget flag, \a f, arguments are passed
+ The \a parent, \a name and widget flag, \a f, arguments are passed
to the TQWidget constructor.
If the \a shareWidget parameter points to a valid TQGLWidget, this
@@ -1314,16 +1314,16 @@ void qgl_delete_d( const TQGLWidget * w )
\sa TQGLFormat::defaultFormat()
*/
-TQGLWidget::TQGLWidget( TQWidget *tqparent, const char *name,
+TQGLWidget::TQGLWidget( TQWidget *parent, const char *name,
const TQGLWidget* shareWidget, WFlags f )
- : TQWidget( tqparent, name, (WFlags)(f | TQt::WWinOwnDC | WNoAutoErase) )
+ : TQWidget( parent, name, (WFlags)(f | TQt::WWinOwnDC | WNoAutoErase) )
{
init( new TQGLContext(TQGLFormat::defaultFormat(), TQT_TQPAINTDEVICE(this)), shareWidget );
}
/*!
- Constructs an OpenGL widget with tqparent \a tqparent, called \a name.
+ Constructs an OpenGL widget with parent \a parent, called \a name.
The \a format argument specifies the desired \link TQGLFormat
rendering options \endlink. If the underlying OpenGL/Window system
@@ -1334,7 +1334,7 @@ TQGLWidget::TQGLWidget( TQWidget *tqparent, const char *name,
The widget will be \link isValid() invalid\endlink if the system
has no \link TQGLFormat::hasOpenGL() OpenGL support\endlink.
- The \a tqparent, \a name and widget flag, \a f, arguments are passed
+ The \a parent, \a name and widget flag, \a f, arguments are passed
to the TQWidget constructor.
If the \a shareWidget parameter points to a valid TQGLWidget, this
@@ -1350,16 +1350,16 @@ TQGLWidget::TQGLWidget( TQWidget *tqparent, const char *name,
\sa TQGLFormat::defaultFormat(), isValid()
*/
-TQGLWidget::TQGLWidget( const TQGLFormat &format, TQWidget *tqparent,
+TQGLWidget::TQGLWidget( const TQGLFormat &format, TQWidget *parent,
const char *name, const TQGLWidget* shareWidget,
WFlags f )
- : TQWidget( tqparent, name, f | (WFlags)(TQt::WWinOwnDC | WNoAutoErase) )
+ : TQWidget( parent, name, f | (WFlags)(TQt::WWinOwnDC | WNoAutoErase) )
{
init( new TQGLContext(format, TQT_TQPAINTDEVICE(this)), shareWidget );
}
/*!
- Constructs an OpenGL widget with tqparent \a tqparent, called \a name.
+ Constructs an OpenGL widget with parent \a parent, called \a name.
The \a context argument is a pointer to the TQGLContext that
you wish to be bound to this widget. This allows you to pass in
@@ -1368,7 +1368,7 @@ TQGLWidget::TQGLWidget( const TQGLFormat &format, TQWidget *tqparent,
The widget will be \link isValid() invalid\endlink if the system
has no \link TQGLFormat::hasOpenGL() OpenGL support\endlink.
- The \a tqparent, \a name and widget flag, \a f, arguments are passed
+ The \a parent, \a name and widget flag, \a f, arguments are passed
to the TQWidget constructor.
If the \a shareWidget parameter points to a valid TQGLWidget, this
@@ -1383,9 +1383,9 @@ TQGLWidget::TQGLWidget( const TQGLFormat &format, TQWidget *tqparent,
\sa TQGLFormat::defaultFormat(), isValid()
*/
-TQGLWidget::TQGLWidget( TQGLContext *context, TQWidget *tqparent,
+TQGLWidget::TQGLWidget( TQGLContext *context, TQWidget *parent,
const char *name, const TQGLWidget *shareWidget, WFlags f )
- : TQWidget( tqparent, name, (WFlags)(f | TQt::WWinOwnDC | WNoAutoErase) )
+ : TQWidget( parent, name, (WFlags)(f | TQt::WWinOwnDC | WNoAutoErase) )
{
init( context, shareWidget );
}
diff --git a/tqtinterface/qt4/src/opengl/tqgl.h b/tqtinterface/qt4/src/opengl/tqgl.h
index 4b6fce4..2f0431f 100644
--- a/tqtinterface/qt4/src/opengl/tqgl.h
+++ b/tqtinterface/qt4/src/opengl/tqgl.h
@@ -277,11 +277,11 @@ class TQM_EXPORT_OPENGL TQGLWidget : public TQWidget, public TQGL
Q_OBJECT
TQ_OBJECT
public:
- TQGLWidget( TQWidget* tqparent=0, const char* name=0,
+ TQGLWidget( TQWidget* parent=0, const char* name=0,
const TQGLWidget* shareWidget = 0, WFlags f=0 );
- TQGLWidget( TQGLContext *context, TQWidget* tqparent, const char* name=0,
+ TQGLWidget( TQGLContext *context, TQWidget* parent, const char* name=0,
const TQGLWidget* shareWidget = 0, WFlags f=0 );
- TQGLWidget( const TQGLFormat& format, TQWidget* tqparent=0, const char* name=0,
+ TQGLWidget( const TQGLFormat& format, TQWidget* parent=0, const char* name=0,
const TQGLWidget* shareWidget = 0, WFlags f=0 );
~TQGLWidget();
@@ -318,7 +318,7 @@ public:
static TQImage convertToGLFormat( const TQImage& img );
void setMouseTracking( bool enable );
- virtual void reparent( TQWidget* tqparent, WFlags f, const TQPoint& p,
+ virtual void reparent( TQWidget* parent, WFlags f, const TQPoint& p,
bool showIt = FALSE );
const TQGLColormap & colormap() const;
diff --git a/tqtinterface/qt4/src/opengl/tqgl_x11_p.h b/tqtinterface/qt4/src/opengl/tqgl_x11_p.h
index cb88352..dfb8acd 100644
--- a/tqtinterface/qt4/src/opengl/tqgl_x11_p.h
+++ b/tqtinterface/qt4/src/opengl/tqgl_x11_p.h
@@ -69,7 +69,7 @@ typedef void (*_glMatrixMode)( GLenum mode );
typedef void (*_glOrtho)( GLdouble left, GLdouble right, GLdouble bottom, GLdouble top, GLdouble near_val, GLdouble far_val );
typedef void (*_glPopAttrib)( void );
typedef void (*_glPopMatrix)( void );
-typedef void (*_glPushAttrib)( GLbitfield tqmask );
+typedef void (*_glPushAttrib)( GLbitfield mask );
typedef void (*_glPushMatrix)( void );
typedef void (*_glRasterPos2i)( GLint x, GLint y );
typedef void (*_glRasterPos3d)( GLdouble x, GLdouble y, GLdouble z );
diff --git a/tqtinterface/qt4/src/opengl/tqgl_x11.cpp b/tqtinterface/qt4/src/opengl/tqgl_x11.cpp
index 2bedfd6..bc6bc0e 100644
--- a/tqtinterface/qt4/src/opengl/tqgl_x11.cpp
+++ b/tqtinterface/qt4/src/opengl/tqgl_x11.cpp
@@ -608,7 +608,7 @@ void *TQGLContext::tryVisual( const TQGLFormat& f, int bufDepth )
if ( useTranspExt ) {
// bug workaround - some systems (eg. FireGL) refuses to return an overlay
// visual if the GLX_TRANSPARENT_TYPE_EXT attribute is specfied, even if
// the implementation supports transtqparent overlays
int tmpSpec[] = { GLX_LEVEL, f.plane(), GLX_TRANSPARENT_TYPE_EXT,
f.rgba() ? GLX_TRANSPARENT_RGB_EXT : GLX_TRANSPARENT_INDEX_EXT,
None };
@@ -623,7 +623,7 @@ void *TQGLContext::tryVisual( const TQGLFormat& f, int bufDepth )
useTranspExtChecked = TRUE;
}
if ( f.plane() && useTranspExt ) {
// Required to avoid non-transtqparent overlay visual(!) on some systems
spec[i++] = GLX_TRANSPARENT_TYPE_EXT;
spec[i++] = f.rgba() ? GLX_TRANSPARENT_RGB_EXT : GLX_TRANSPARENT_INDEX_EXT;
}
@@ -985,7 +985,7 @@ class TQGLOverlayWidget : public TQGLWidget
{
TQ_OBJECT
public:
- TQGLOverlayWidget( const TQGLFormat& format, TQGLWidget* tqparent,
+ TQGLOverlayWidget( const TQGLFormat& format, TQGLWidget* parent,
const char* name=0, const TQGLWidget* shareWidget=0 );
protected:
@@ -1004,12 +1004,12 @@ private: // Disabled copy constructor and operator=
};
-TQGLOverlayWidget::TQGLOverlayWidget( const TQGLFormat& format, TQGLWidget* tqparent,
+TQGLOverlayWidget::TQGLOverlayWidget( const TQGLFormat& format, TQGLWidget* parent,
const char* name,
const TQGLWidget* shareWidget )
- : TQGLWidget( format, tqparent, name, shareWidget ? shareWidget->olw : 0 )
+ : TQGLWidget( format, parent, name, shareWidget ? shareWidget->olw : 0 )
{
- realWidget = tqparent;
+ realWidget = parent;
}
@@ -1020,7 +1020,7 @@ void TQGLOverlayWidget::initializeGL()
if ( transparentColor.isValid() )
qglClearColor( transparentColor );
else
- qWarning( "TQGLOverlayWidget::initializeGL(): Could not get transtqparent color" );
+ qWarning( "TQGLOverlayWidget::initializeGL(): Could not get transparent color" );
realWidget->initializeOverlayGL();
}
@@ -1077,12 +1077,12 @@ void TQGLWidget::init( TQGLContext *context, const TQGLWidget *shareWidget )
}
/*! \reimp */
-void TQGLWidget::reparent( TQWidget* tqparent, WFlags f, const TQPoint& p,
+void TQGLWidget::reparent( TQWidget* parent, WFlags f, const TQPoint& p,
bool showIt )
{
if (glcx)
glcx->doneCurrent();
- TQWidget::reparent( tqparent, f, p, FALSE );
+ TQWidget::reparent( parent, f, p, FALSE );
if ( showIt )
show();
}
@@ -1308,15 +1308,15 @@ static bool qCanAllocColors( TQWidget * w )
{
bool validVisual = FALSE;
int numVisuals;
- long tqmask;
+ long mask;
XVisualInfo templ;
XVisualInfo * visuals;
VisualID id = XVisualIDFromVisual( (Visual *)
w->tqtopLevelWidget()->x11Visual() );
- tqmask = VisualScreenMask;
+ mask = VisualScreenMask;
templ.screen = w->x11Screen();
- visuals = XGetVisualInfo( w->x11Display(), tqmask, &templ, &numVisuals );
+ visuals = XGetVisualInfo( w->x11Display(), mask, &templ, &numVisuals );
for ( int i = 0; i < numVisuals; i++ ) {
if ( visuals[i].visualid == id ) {
@@ -608,7 +608,7 @@ void *TQGLContext::tryVisual( const TQGLFormat& f, int bufDepth )
// bug workaround - some systems (eg. FireGL) refuses to return an overlay
// visual if the GLX_TRANSPARENT_TYPE_EXT attribute is specfied, even if
- // the implementation supports transtqparent overlays
+ // the implementation supports transparent overlays
int tmpSpec[] = { GLX_LEVEL, f.plane(), GLX_TRANSPARENT_TYPE_EXT,
f.rgba() ? GLX_TRANSPARENT_RGB_EXT : GLX_TRANSPARENT_INDEX_EXT,
@@ -623,7 +623,7 @@ void *TQGLContext::tryVisual( const TQGLFormat& f, int bufDepth )
}
if ( f.plane() && useTranspExt ) {
- // Required to avoid non-transtqparent overlay visual(!) on some systems
+ // Required to avoid non-transparent overlay visual(!) on some systems
spec[i++] = GLX_TRANSPARENT_TYPE_EXT;
spec[i++] = f.rgba() ? GLX_TRANSPARENT_RGB_EXT : GLX_TRANSPARENT_INDEX_EXT;